import subprocess
import argparse
import time
import sys
from .notifications import send_notification

def main():
    parser = argparse.ArgumentParser(
        prog="termiredy",
        description="A terminal tool that notifies you when your task is done."
    )

    parser.add_argument("command", nargs=argparse.REMAINDER)

    args = parser.parse_args()

    if not args.command:
        print("\n> You must provide a command to run.\nExample: termiredy python work.py")
        sys.exit(1)

    t1 = time.time()
    try:
        subprocess.run(" ".join(args.command), shell=True)
    except KeyboardInterrupt as e:
        print("\n> Command execution interrupted by user.")
    print(f"\n> Your command is done! It took {time.time() - t1:.2f} seconds.")
    send_notification("Termiredy", "Your command is done!")



from setuptools import setup, find_packages

setup(
    name="termiredy",
    version="0.1.0",
    packages=find_packages(),
    entry_points={
        "console_scripts": [
            "termiredy = termiredy.cli:main",
        ]
    },
)



import platform
import subprocess
import sys

def send_notification(title: str, message: str):
    system = platform.system()

    if system == "Darwin":  # macOS
        safe_title = title.replace('"', '\\"')
        safe_message = message.replace('"', '\\"')
        script = f'display notification "{safe_message}" with title "{safe_title}"'
        # script = f'display alert "{safe_message}" message "{safe_title}"' 
        # TODO: Add a mode switch parameter to choose between notification and alert.
        subprocess.run(["osascript", "-e", script])

    elif system == "Linux":
        # linux need to have notify-send（libnotify-bin）
        # sudo apt install libnotify-bin
        subprocess.run(["notify-send", title, message])
    else:
        # Unknown system, fallback to print
        print(f"[{title}] {message}")
